==> marquee_1.0.0.tar.gz: marquee/tests/testthat/_snaps/style.md <==
# style checks it's inputs

    `family` must be a single string or `NULL`, not a character vector.

---

    `family` must be a single string or `NULL`, not the number 1.

---

    `weight` must be one of "undefined", "thin", "ultralight", "light", "normal", "medium", "semibold", "bold", "ultrabold", or "heavy"

---

    `weight` must be a whole number or `NULL`, not `TRUE`.

---

    `italic` must be `TRUE`, `FALSE`, or `NULL`, not the string "A".

---

    `italic` must be `TRUE`, `FALSE`, or `NULL`, not the number 1.

---

    `width` must be one of "undefined", "ultracondensed", "extracondensed", "condensed", "semicondensed", "normal", "semiexpanded", "expanded", "extraexpanded", or "ultraexpanded"

---

    `width` must be a whole number or `NULL`, not `TRUE`.

---

    `features` must be a font_feature object or `NULL`, not the string "A".

---

    `features` must be a font_feature object or `NULL`, not the number 1.

---

    `size` must be a number or `NULL`, not the string "A".

---

    `size` must be a number or `NULL`, not `TRUE`.

---

    `color` must be a single string, `NA`, or `NULL`, not the number 1.

---

    `color` must be a single string, `NA`, or `NULL`, not `TRUE`.

---

    `lineheight` must be a number or `NULL`, not the string "A".

---

    `lineheight` must be a number or `NULL`, not `TRUE`.

---

    `lineheight` must be a number or `NULL`, not a <marquee_em> object.

---

    `lineheight` must be a number or `NULL`, not a <marquee_rem> object.

---

    `align` must be a single string or `NULL`, not the number 1.

---

    `align` must be a single string or `NULL`, not `TRUE`.

---

    `tracking` must be a number or `NULL`, not the string "A".

---

    `tracking` must be a number or `NULL`, not `TRUE`.

---

    `tracking` must be a number or `NULL`, not a <marquee_em> object.

---

    `tracking` must be a number or `NULL`, not a <marquee_rem> object.

---

    `indent` must be a number or `NULL`, not the string "A".

---

    `indent` must be a number or `NULL`, not `TRUE`.

---

    `hanging` must be a number or `NULL`, not the string "A".

---

    `hanging` must be a number or `NULL`, not `TRUE`.

---

    `margin` must be a marquee_trbl object or `NULL`, not the string "A".

---

    `margin` must be a marquee_trbl object or `NULL`, not `TRUE`.

---

    `padding` must be a marquee_trbl object or `NULL`, not the string "A".

---

    `padding` must be a marquee_trbl object or `NULL`, not `TRUE`.

---

    `unclass(background)` must be a single string, `NA`, or `NULL`, not the number 1.

---

    `unclass(background)` must be a single string, `NA`, or `NULL`, not `TRUE`.

---

    `border` must be a single string, `NA`, or `NULL`, not the number 1.

---

    `border` must be a single string, `NA`, or `NULL`, not `TRUE`.

---

    `border_size` must be a marquee_trbl object or `NULL`, not the string "A".

---

    `border_size` must be a marquee_trbl object or `NULL`, not `TRUE`.

---

    `border_radius` must be a number or `NULL`, not the string "A".

---

    `border_radius` must be a number or `NULL`, not `TRUE`.

---

    `bullets` must be a character vector or `NULL`, not the number 1.

---

    `bullets` must be a character vector or `NULL`, not `TRUE`.

---

    `underline` must be `TRUE`, `FALSE`, or `NULL`, not the string "A".

---

    `underline` must be `TRUE`, `FALSE`, or `NULL`, not the number 1.

---

    `strikethrough` must be `TRUE`, `FALSE`, or `NULL`, not the string "A".

---

    `strikethrough` must be `TRUE`, `FALSE`, or `NULL`, not the number 1.

---

    `baseline` must be a number or `NULL`, not the string "A".

---

    `baseline` must be a number or `NULL`, not `TRUE`.

---

    `img_asp` must be a number or `NULL`, not the string "A".

---

    `img_asp` must be a number or `NULL`, not `TRUE`.

==> marquee_1.2.0.tar.gz: marquee/tests/testthat/_snaps/style.md <==
# style checks it's inputs

    `family` must be a single string or `NULL`, not a character vector.

---

    `family` must be a single string or `NULL`, not the number 1.

---

    `weight` must be one of "undefined", "thin", "ultralight", "light", "normal", "medium", "semibold", "bold", "ultrabold", or "heavy"

---

    `weight` must be a whole number or `NULL`, not `TRUE`.

---

    `italic` must be `TRUE`, `FALSE`, or `NULL`, not the string "A".

---

    `italic` must be `TRUE`, `FALSE`, or `NULL`, not the number 1.

---

    `width` must be one of "undefined", "ultracondensed", "extracondensed", "condensed", "semicondensed", "normal", "semiexpanded", "expanded", "extraexpanded", or "ultraexpanded"

---

    `width` must be a whole number or `NULL`, not `TRUE`.

---

    `features` must be a font_feature object or `NULL`, not the string "A".

---

    `features` must be a font_feature object or `NULL`, not the number 1.

---

    `size` must be a number or `NULL`, not the string "A".

---

    `size` must be a number or `NULL`, not `TRUE`.

---

    `color` must be a single string, `NA`, or `NULL`, not the number 1.

---

    `color` must be a single string, `NA`, or `NULL`, not `TRUE`.

---

    `lineheight` must be a number or `NULL`, not the string "A".

---

    `lineheight` must be a number or `NULL`, not `TRUE`.

---

    `lineheight` must be a number or `NULL`, not a <marquee_em> object.

---

    `lineheight` must be a number or `NULL`, not a <marquee_rem> object.

---

    `align` must be a single string or `NULL`, not the number 1.

---

    `align` must be a single string or `NULL`, not `TRUE`.

---

    `tracking` must be a number or `NULL`, not the string "A".

---

    `tracking` must be a number or `NULL`, not `TRUE`.

---

    `tracking` must be a number or `NULL`, not a <marquee_em> object.

---

    `tracking` must be a number or `NULL`, not a <marquee_rem> object.

---

    `indent` must be a number or `NULL`, not the string "A".

---

    `indent` must be a number or `NULL`, not `TRUE`.

---

    `hanging` must be a number or `NULL`, not the string "A".

---

    `hanging` must be a number or `NULL`, not `TRUE`.

---

    `margin` must be a marquee_trbl object or `NULL`, not the string "A".

---

    `margin` must be a marquee_trbl object or `NULL`, not `TRUE`.

---

    `padding` must be a marquee_trbl object or `NULL`, not the string "A".

---

    `padding` must be a marquee_trbl object or `NULL`, not `TRUE`.

---

    `unclass(background)` must be a single string, `NA`, or `NULL`, not the number 1.

---

    `unclass(background)` must be a single string, `NA`, or `NULL`, not `TRUE`.

---

    `border` must be a single string, `NA`, or `NULL`, not the number 1.

---

    `border` must be a single string, `NA`, or `NULL`, not `TRUE`.

---

    `border_width` must be a marquee_trbl object or `NULL`, not the string "A".

---

    `border_width` must be a marquee_trbl object or `NULL`, not `TRUE`.

---

    `border_radius` must be a number or `NULL`, not the string "A".

---

    `border_radius` must be a number or `NULL`, not `TRUE`.

---

    `bullets` must be a character vector or `NULL`, not the number 1.

---

    `bullets` must be a character vector or `NULL`, not `TRUE`.

---

    `underline` must be `TRUE`, `FALSE`, or `NULL`, not the string "A".

---

    `underline` must be `TRUE`, `FALSE`, or `NULL`, not the number 1.

---

    `strikethrough` must be `TRUE`, `FALSE`, or `NULL`, not the string "A".

---

    `strikethrough` must be `TRUE`, `FALSE`, or `NULL`, not the number 1.

---

    `baseline` must be a number or `NULL`, not the string "A".

---

    `baseline` must be a number or `NULL`, not `TRUE`.

---

    `img_asp` must be a number or `NULL`, not the string "A".

---

    `img_asp` must be a number or `NULL`, not `TRUE`.
